==> xwidgetsbase-8.3.8.tar.gz: lib/XWidgets/XDD/XDDGeneric.dart <==
part of xwidgetbase;

class XDDGeneric extends StatefulWidget {
  XDDGeneric({
    Key? key,
    this.ddColorBTN,
    this.ddColorMenu,
    this.ddColorItem,
    this.selectedItemHeight,
    this.filterItems,
    this.filterValue,
    this.onChangeDD,
    this.hintText,
    this.ddColorTextInItem,
  }) : super(key: key);
  Object? filterValue;
  List<String>? filterItems;
  String? hintText;
  Function(Object?)? onChangeDD;
  Color? ddColorBTN;
  Color? ddColorMenu;
  Color? ddColorItem;
  double? selectedItemHeight;
  Color? ddColorTextInItem;
  @override
  _XDDGenericState createState() => _XDDGenericState();
}

class _XDDGenericState extends State<XDDGeneric> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(children: [
      Expanded(
          child: Container(
              child: DropdownButtonHideUnderline(
                  child: GFDropdown(
                      itemHeight: widget.selectedItemHeight ?? 50,
                      hint: Text(widget.hintText ?? "inserisci"),
                      elevation: 8,
                      border: BorderSide(color: Colors.black12, width: 1),
                      dropdownButtonColor: widget.ddColorBTN ?? Colors.white,
                      style: XStyles.xStyTextForTextBase(),
                      iconDisabledColor: XColors.xcolor_ForegroundDark,
                      iconEnabledColor: XColors.xcolor_ForegroundDark,
                      dropdownColor: widget.ddColorBTN,
                      isExpanded: true,
                      isDense: true,
                      value: widget.filterValue,
                      onTap: () {},
                      onChanged: widget.onChangeDD!,
                      items: widget.filterItems!
                          .map((value) => DropdownMenuItem(
                              value: value,
                              child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                                Expanded(
                                    child: Container(
                                  margin: EdgeInsets.only(top: 3, bottom: 3),
                                  alignment: Alignment.center,
                                  color: widget.ddColorItem ?? Colors.grey[600],
                                  child: Text(value, overflow: TextOverflow.ellipsis, style: XStyles.xStyTextForDescr(widget.ddColorTextInItem ?? XColors.xcolor_ForegroundLight)),
                                ))
                              ])))
                          .toList()))))
    ]);
  }
}

==> xwidgetsbase-8.7.7.tar.gz: lib/XWidgets/XDD/XDDGeneric.dart <==
part of xwidgetbase;

class XDDGeneric extends StatefulWidget {
  XDDGeneric({
    Key? key,
    this.ddColorBTN,
    this.ddColorMenu,
    this.ddColorItem,
    this.selectedItemHeight,
    this.filterItems,
    this.filterValue,
    this.onChangeDD,
    this.hintText,
    this.padding,
    this.ddColorTextInItem,
  }) : super(key: key);
  String? filterValue;
  List<String>? filterItems;
  String? hintText;
  Function(Object?)? onChangeDD;
  Color? ddColorBTN;
  Color? ddColorMenu;
  Color? ddColorItem;
  double? selectedItemHeight;
  Color? ddColorTextInItem;
  EdgeInsets? padding;
  @override
  _XDDGenericState createState() => _XDDGenericState();
}

class _XDDGenericState extends State<XDDGeneric> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Row(children: [
      Expanded(
          child: Container(
              child: DropdownButtonHideUnderline(
                  child: GFDropdown(
                      itemHeight: widget.selectedItemHeight ?? 50,
                      hint: Text(widget.hintText ?? "inserisci"),
                      elevation: 8,
                      padding: widget.padding ?? EdgeInsets.all(5),
                      border: BorderSide(color: Colors.black12, width: 1),
                      dropdownButtonColor: widget.ddColorBTN ?? Colors.white,
                      style: XStyles.xStyTextForTextBase(),
                      iconDisabledColor: XColors.xcolor_ForegroundDark,
                      iconEnabledColor: XColors.xcolor_ForegroundDark,
                      dropdownColor: widget.ddColorMenu,
                      isExpanded: true,
                      isDense: true,
                      value: widget.filterValue,
                      onTap: () {},
                      onChanged: widget.onChangeDD!,
                      items: widget.filterItems!
                          .map((value) => DropdownMenuItem(
                              value: value,
                              child: Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                                Expanded(
                                    child: Container(
                                  margin: EdgeInsets.only(top: 3, bottom: 3),
                                  alignment: Alignment.center,
                                  color: widget.ddColorItem ?? Colors.grey[600],
                                  child: Text(value, overflow: TextOverflow.ellipsis, style: XStyles.xStyTextForDescr(widget.ddColorTextInItem ?? XColors.xcolor_ForegroundLight)),
                                ))
                              ])))
                          .toList()))))
    ]);
  }
}
